# by: Johannes Kinzig
# web: https://siincos.de/blog

from pyModbusTCP.client import ModbusClient

def lg8add(logo_modbustcp_address: int) -> int:
    """
    Logo8 uses modbusTCP +1 address offset
    to stay conform with their documentation, subtract 1 from each given address
    """
    return logo_modbustcp_address-1


lg8 = ModbusClient(host="1.1.2.1", port=503, auto_open=True, auto_close=True)
# ->  logo 8 read digital inputs <- #
di1 = lg8.read_discrete_inputs(lg8add(1), 1) # read DI 1
di2 = lg8.read_discrete_inputs(lg8add(2), 1) # read DI 2
di3 = lg8.read_discrete_inputs(lg8add(3), 1) # read DI 3

# -> logo 8 write digital outputs <- #
lg8.write_single_coil(lg8add(8193), True) # write DO 1
lg8.write_single_coil(lg8add(8194), True) # write DO 1

# -> logo 8 read digital outputs <- #
do1 = lg8.read_coils(lg8add(8193), 1) # read DO 1 state
do2 = lg8.read_coils(lg8add(8194), 1) # read DO 2 state

# -> logo 8 read analog inputs <- #
ai1 = lg8.read_input_registers(lg8add(1), 1) # read AI 1 directly
ai1_vmmapping = lg8.read_holding_registers(lg8add(1), 1) # read AI 1 using parameter VM mapping - VW 0
am1 = lg8.read_holding_registers(lg8add(529), 1) # read AI 1 using AM1

ai2 = lg8.read_input_registers(lg8add(2), 1) # read AI 2 directly
ai2_vmmapping = lg8.read_holding_registers(lg8add(2), 1) # read AI 2 using parameter VM mapping - VW 2
am2 = lg8.read_holding_registers(lg8add(530), 1) # read AI 2 using AM2

ai3 = lg8.read_input_registers(lg8add(3), 1) # read AI 3 directly
ai3_vmmapping = lg8.read_holding_registers(lg8add(3), 1) # read AI 3 using parameter VM mapping - VW 4
am3 = lg8.read_holding_registers(lg8add(531), 1) # read AI 3 using AM3

ai4 = lg8.read_input_registers(lg8add(4), 1) # read AI 4 directly
ai4_vmmapping = lg8.read_holding_registers(lg8add(4), 1) # read AI 4 using parameter VM mapping - VW 6
am4 = lg8.read_holding_registers(lg8add(532), 1) # read AI 4 using AM4

print("DI 1: ", str(di1))
print("DI 2: ", str(di2))
print("DI 3: ", str(di3))

print("DO 1: ", str(do1))
print("DO 2: ", str(do2))

print("AI 1: ", str(ai1), str(ai1_vmmapping), str(am1))
print("AI 2: ", str(ai2), str(ai2_vmmapping), str(am2))
print("AI 3: ", str(ai3), str(ai3_vmmapping), str(am3))
print("AI 4: ", str(ai4), str(ai4_vmmapping), str(am4))

